@@ -95,6 +95,9 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         <li>Het backup filesystem werd recentelijk aangevuld voor \$Info{DUlastValue}%
             op (\$DUlastTime), het maximum van vandaag is \$Info{DUDailyMax}% (\$DUmaxTime)
             en het maximum van gisteren was \$Info{DUDailyMaxPrev}%.
+        <li>Het backup filesystem inode werd recentelijk aangevuld voor \$Info{DUInodelastValue}%
+            op (\$DUlastTime), het maximum van vandaag is \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+            en het maximum van gisteren was \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -105,7 +108,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \${h2("Momenteel lopende jobs")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Machine </td>
     <td> Type </td>
     <td> Gebruiker </td>
@@ -124,7 +127,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 
 \${h2("Opgetreden fouten die aandacht vragen")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Machine </td>
     <td align="center"> Type </td>
     <td align="center"> Gebruiker </td>
@@ -148,6 +151,9 @@ $Lang{BackupPC_Summary}=<<EOF;
 <li>Het backup filesystem werd recentelijk aangevuld voor \$Info{DUlastValue}%
      op (\$DUlastTime), het maximum van vandaag is \$Info{DUDailyMax}% (\$DUmaxTime)
      en het maximum van gisteren was \$Info{DUDailyMaxPrev}%.
+<li>Het backup filesystem inode werd recentelijk aangevuld voor \$Info{DUInodelastValue}%
+    op (\$DUlastTime), het maximum van vandaag is \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    en het maximum van gisteren was \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -379,8 +385,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 Deze aanvragen van gebruikers staan momenteel in de wachtrij:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Machine </td>
+    <td> Action </td>
     <td> Aanvraagtijd </td>
     <td> Gebruiker </td></tr>
 \$strUser
@@ -390,8 +397,9 @@ Deze aanvragen van gebruikers staan momenteel in de wachtrij:
 <p>
 Deze aanvragen voor backups in de achtergrond staan momenteel in de wachtrij:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Machine </td>
+    <td> Action </td>
     <td> Aanvraagtijd </td>
     <td> Gebruiker </td></tr>
 \$strBg
@@ -400,8 +408,9 @@ Deze aanvragen voor backups in de achtergrond staan momenteel in de wachtrij:
 <p>
 Deze aanvragen via opdracht staan momenteel in de wachtrij:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Machine </td>
+    <td> Action </td>
     <td> Aanvraagtijd </td>
     <td> Gebruiker </td>
     <td> Opdracht </td></tr>
@@ -430,7 +439,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Geschiedenis Logbestand";
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Geschiedenis Logbestand \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Bestand </td>
     <td align="center"> Grootte </td>
     <td align="center"> Laatste wijziging </td></tr>
@@ -442,7 +451,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Overzicht recente e-mail (Omgekeerde volgorde)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Bestemming </td>
     <td align="center"> Machine </td>
     <td align="center"> Tijd </td>
@@ -706,7 +715,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Klik op het backupnummer om de inhoud te bekijken of om bestanden te herstellen.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> backup nr.</td>
     <td align="center"> Type </td>
     <td align="center"> Aangevuld </td>
@@ -714,7 +723,7 @@ Klik op het backupnummer om de inhoud te bekijken of om bestanden te herstellen.
     <td align="center"> Startdatum </td>
     <td align="center"> Duurtijd in min. </td>
     <td align="center"> Lftd. in dagen </td>
-    <td align="center"> </td>
+    \$deleteHdrStr
     <td align="center"> Plaats op de server </td>
 </tr>
 \$str
@@ -724,7 +733,7 @@ Klik op het backupnummer om de inhoud te bekijken of om bestanden te herstellen.
 \$restoreStr
 </p>
 \${h2("Overzicht van fouten tijdens overdracht")}
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> backup nr. </td>
     <td align="center"> Type </td>
     <td align="center"> Bekijken </td>
@@ -742,13 +751,13 @@ Bestaande bestanden zijn bestanden die reeds aanwezig waren op de backupschijf.
 Nieuwe bestanden zijn bestanden die aan de schijf zijn toegevoegd.
 Lege bestanden en SMB-fouten worden niet geteld in de aantallen \'hergebruik\' en \'nieuw\'.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Totalen </td>
     <td align="center" colspan="2"> Bestaande bestanden </td>
     <td align="center" colspan="2"> Nieuwe bestanden </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Backup nr. </td>
     <td align="center"> Type </td>
     <td align="center"> Aantal best.</td>
@@ -767,12 +776,12 @@ Lege bestanden en SMB-fouten worden niet geteld in de aantallen \'hergebruik\' e
 Compressie van bestanden die reeds op schijf stonden en van nieuw
 gecomprimeerde bestanden.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Bestaande bestanden </td>
     <td align="center" colspan="3"> Nieuwe bestanden </td>
 </tr>
-<tr class="tableheader"><td align="center"> backup nr. </td>
+<tr class="tableheader sortheader"><td align="center"> backup nr. </td>
     <td align="center"> Type </td>
     <td align="center"> Comp.niveau </td>
     <td align="center"> Grootte in MB </td>
@@ -1218,7 +1227,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Overzicht herstellingen")}
 <p>
 Klik op het nummer voor meer details.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Herstel nr.</td>
     <td align="center"> Resultaat </td>
     <td align="right"> Startdatum</td>
@@ -1325,7 +1334,7 @@ systeembeheerder.
 
 Met vriendelijke groeten,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1358,7 +1367,7 @@ van uw pc zou crashen. Hierin zijn nieuwe e-mail en bijlagen inbegrepen.
 
 Met vriendelijke groeten,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1396,7 +1405,7 @@ vragen vooraleer de backup volledig is.
 
 Met vriendelijke groeten,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "(nog) niet succesvol gebackupt";
@@ -1415,6 +1424,7 @@ Snelheid MB/sec: \$fullRate;
 Aantal Incr.: \$incrCnt;
 Incr.Lftd/dagen: \$incrAge;
 Status: \$host_state;
+Invalide: \$host_disabled;
 Laatste poging: \$host_last_attempt;
 EOF
 
